@@ -1,8 +1,8 @@
-use web_sys::{window, Window};
+use gloo::utils::window;
 
 use yew::prelude::*;
 
-use super::{use_event_with_window, use_raf_state};
+use super::{use_event_with_window, use_mount, use_raf_state};
 
 /// A sensor hook that tracks dimensions of the browser window.
 ///
@@ -30,18 +30,27 @@ use super::{use_event_with_window, use_raf_state};
 pub fn use_window_size() -> (f64, f64) {
     let state = use_raf_state(|| {
         (
-            window().unwrap().inner_width().unwrap().as_f64().unwrap(),
-            window().unwrap().inner_height().unwrap().as_f64().unwrap(),
+            window().inner_width().unwrap().as_f64().unwrap(),
+            window().inner_height().unwrap().as_f64().unwrap(),
         )
     });
 
     {
         let state = state.clone();
-        use_event_with_window("resize", move |e: Event| {
-            let window: Window = e.target_unchecked_into();
+        use_event_with_window("resize", move |_: Event| {
             state.set((
-                window.inner_width().unwrap().as_f64().unwrap(),
-                window.inner_height().unwrap().as_f64().unwrap(),
+                window().inner_width().unwrap().as_f64().unwrap(),
+                window().inner_height().unwrap().as_f64().unwrap(),
+            ));
+        });
+    }
+
+    {
+        let state = state.clone();
+        use_mount(move || {
+            state.set((
+                window().inner_width().unwrap().as_f64().unwrap(),
+                window().inner_height().unwrap().as_f64().unwrap(),
             ));
         });
     }
